#!/bin/bash

# $Id$
#####################################################################
# Written and maintained by:
#    Stefan Jakobs <projects at localside.net>
#
# Please send all comments, suggestions, bug reports,
#    etc, to <projects at localside.net>.
#####################################################################
# Copyright (c) 2017 Stefan Jakobs
# License GPL-3
#####################################################################

Version="0.5.5 (11.07.2017)"
Name="expire-sa.sh"
Conf="/etc/mail/spamassassin/expire-sa.conf"

function usage {
   echo "$Name"
   echo "All configuration options will be read from $Conf"
   exit 0
}

function version {
   echo "$Name: $Version"
   exit 0
}

while getopts 'hv' OPT; do
   case $OPT in
      h)   usage ;;
      v)   version ;;
      *)   usage ;;
   esac
done

if [ -r "$Conf" ]; then
   source "$Conf"
fi

# set defaults
SA_EXPIRE_LOG=${SA_EXPIRE_LOG:=/var/log/expire-sa.log}
SA_DB_PATH=${SA_DB_PATH:=/var/spool/amavis/.spamassassin}
USER_PREFS=${USER_PREFS:=${SA_DB_PATH}/user_prefs}
SA_USER=${SA_USER:=vscan}

# log and run expire
echo "##### $(/bin/date +%d.%m.%Y-%R) : #####" >> $SA_EXPIRE_LOG
/usr/bin/sa-learn --dbpath $SA_DB_PATH -p $USER_PREFS -u $SA_USER --force-expire >> $SA_EXPIRE_LOG 2>&1

# if owner of bayes_* is root, then change to $SA_USER
for bfile in $SA_DB_PATH/bayes_*; do
  chown $SA_USER:$SA_USER ${bfile}
done

